Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(48)

Unified Diff: runtime/vm/class_finalizer.h

Issue 9615035: Generate dynamic type errors according to spec. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/vm/class_finalizer.h
===================================================================
--- runtime/vm/class_finalizer.h (revision 5060)
+++ runtime/vm/class_finalizer.h (working copy)
@@ -60,8 +60,9 @@
// Replace the malformed type with Dynamic and, depending on the given type
// finalization mode and execution mode, mark the type as malformed or report
- // a compile time error.
- static void FinalizeMalformedType(const Class& cls,
+ // a compile time error. Prepend prev_error if not null.
+ static void FinalizeMalformedType(const Error& prev_error,
+ const Class& cls,
const Type& type,
FinalizationKind finalization,
const char* format, ...);

Powered by Google App Engine
This is Rietveld 408576698